# Import all 2D modules

from .square import *
from .init import *
from .helper import *
from .triangle import *
from .circle import *
from .shape import *
from .mouse import *
from .arc import *
from .bezier_curve import *
from .ellipse import *
from .heart import *
from .line import *
from .polygon import *
from .star import *
from .control import *
